import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

public class MajorityByRange
{
    public static void main( String[] args ) throws IOException
    {
        String filename           = args[0];
        int    numberOfCandidates = Integer.parseInt(args[1]);

        int    numberOfRanges     = (int) Math.sqrt(numberOfCandidates);

        if ( numberOfRanges*numberOfRanges != numberOfCandidates)
        {
            System.out.println( "number of candidates must be a square" );
            System.exit(-1);
        }

        // Pass 1 -- compute votes in ranges

        int   numberOfVotes = 0;
        int[] rangeTally    = new int[numberOfRanges];
        for (int i = 0; i < numberOfRanges; i++)
            rangeTally[i] = 0;

        BufferedReader in = new BufferedReader(new FileReader(filename));
        while (true)
        {
            String voteString = in.readLine();
            if (voteString == null) break;
            numberOfVotes++;
            int vote = Integer.parseInt(voteString);
            int slot = (vote-1) / numberOfRanges;
            rangeTally[slot]++;
        }
        in.close();

        int majority = numberOfVotes/2 + 1;

        // Check need for Pass 2 -- determine if a range has a majority

        int i;
        for (i = 0; i < numberOfRanges; i++)
            if (rangeTally[i] >= majority)
                break;
        if (i >= numberOfRanges)
        {
            System.out.println( "no majority candidate" );
            System.exit(0);
        }

        // Pass 2 -- compute votes for candidates in majority range

        int majorityRange = i;
        int lowCandidate  = majorityRange * numberOfRanges;
        int highCandidate = (majorityRange+1) * numberOfRanges - 1;

        for (i = 0; i < numberOfRanges; i++)
            rangeTally[i] = 0;

        in = new BufferedReader(new FileReader(filename));
        while (true)
        {
            String voteString = in.readLine();
            if (voteString == null) break;
            int vote = Integer.parseInt(voteString);
            int voteSlot = vote - 1;
            if (lowCandidate <= voteSlot && voteSlot <= highCandidate)
                rangeTally[voteSlot-lowCandidate]++;
        }
        in.close();

        // Check for answer -- determine if a slot has a majority

        for (i = 0; i < numberOfRanges; i++)
            if (rangeTally[i] >= majority)
                break;
        if (i >= numberOfRanges)
        {
            System.out.println( "no majority candidate" );
            System.exit(0);
        }

        System.out.println( "majority candidate " + (lowCandidate + i + 1) );
    }
}
